# highway_sdk.QueriesApi

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_api_v1_workflowsworkflow_run_id_query**](QueriesApi.md#get_api_v1_workflowsworkflow_run_id_query) | **GET** /api/v1/workflows/{workflow_run_id}/query | Query workflow state.


# **get_api_v1_workflowsworkflow_run_id_query**
> get_api_v1_workflowsworkflow_run_id_query(workflow_run_id)

Query workflow state.

Query Parameters:     variable: Specific variable name to query     all: If "true", return all variables     include_version: If "true", include version info for optimistic locking

### Example

* Bearer (JWT) Authentication (BearerAuth):

```python
import highway_sdk
from highway_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = highway_sdk.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): BearerAuth
configuration = highway_sdk.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with highway_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = highway_sdk.QueriesApi(api_client)
    workflow_run_id = 'workflow_run_id_example' # str | 

    try:
        # Query workflow state.
        api_instance.get_api_v1_workflowsworkflow_run_id_query(workflow_run_id)
    except Exception as e:
        print("Exception when calling QueriesApi->get_api_v1_workflowsworkflow_run_id_query: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **workflow_run_id** | **str**|  | 

### Return type

void (empty response body)

### Authorization

[BearerAuth](../README.md#BearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

